@@ -156,7 +156,7 @@ activityRadial <- function(recordTable,
 
   if(allSpecies == FALSE){
 
-    subset_species <- subset(recordTable, recordTable[,speciesCol] == species)
+    subset_species <- recordTable[recordTable[,speciesCol] == species,]
     lengths.tmp <- table(subset_species$Time2)
 
     seq.tmp <- data.frame(hour = seq(0,23, length.out = 24),
@@ -177,7 +177,7 @@ activityRadial <- function(recordTable,
                    clockwise = TRUE,
                    start = (pi/2),
                    labels = paste(formatC(seq.tmp$hour, width = 2,  flag = 0), "00", sep = ""),
-                   main = paste("Activity of", species),
+                   main = species,
                    boxed.radial = FALSE,
                    ...)
       #title(main = paste("Activity of", species), line = 3)
@@ -189,7 +189,7 @@ activityRadial <- function(recordTable,
                    clockwise = TRUE,
                    start = (pi/2),
                    labels = paste(formatC(seq.tmp$hour, width = 2,  flag = 0), "00", sep = ""),
-                   main = paste("Activity of", species),
+                   main = species,
                    boxed.radial = FALSE,
                    ...)
       #title(main = paste("Activity of", species), line = 3)
@@ -225,7 +225,7 @@ activityRadial <- function(recordTable,
                      clockwise = TRUE,
                      start = (pi/2),
                      labels = paste(formatC(seq.tmp$hour, width = 2,  flag = 0), "00", sep = ""),
-                     main = paste("Activity of", spec.tmp),
+                     main = spec.tmp,
                      boxed.radial = FALSE,
                      ...)
         #title(main = paste("Activity of", spec.tmp), line = 3)             
@@ -238,7 +238,7 @@ activityRadial <- function(recordTable,
                      clockwise = TRUE,
                      start = (pi/2),
                      labels = paste(formatC(seq.tmp$hour, width = 2,  flag = 0), "00", sep = ""),
-                     main = paste("Activity of", spec.tmp),
+                     main = spec.tmp,
                      boxed.radial = FALSE,
                      ...)
         #title(main = paste("Activity of", spec.tmp), line = 3)             
